package com.bonus.material.input.mapper;

import java.util.List;
import com.bonus.material.input.domain.InputApplyDetails;

/**
 * 入库任务详细Mapper接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface InputApplyDetailsMapper {
    /**
     * 查询入库任务详细
     * 
     * @param id 入库任务详细主键
     * @return 入库任务详细
     */
    public InputApplyDetails selectInputApplyDetailsById(Long id);

    /**
     * 查询入库任务详细列表
     * 
     * @param inputApplyDetails 入库任务详细
     * @return 入库任务详细集合
     */
    public List<InputApplyDetails> selectInputApplyDetailsList(InputApplyDetails inputApplyDetails);

    /**
     * 新增入库任务详细
     * 
     * @param inputApplyDetails 入库任务详细
     * @return 结果
     */
    public int insertInputApplyDetails(InputApplyDetails inputApplyDetails);

    /**
     * 修改入库任务详细
     * 
     * @param inputApplyDetails 入库任务详细
     * @return 结果
     */
    public int updateInputApplyDetails(InputApplyDetails inputApplyDetails);

    /**
     * 删除入库任务详细
     * 
     * @param id 入库任务详细主键
     * @return 结果
     */
    public int deleteInputApplyDetailsById(Long id);

    /**
     * 批量删除入库任务详细
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInputApplyDetailsByIds(Long[] ids);

    int updateTaskStatus(InputApplyDetails inputApplyDetails);

    int updateStorageNum(InputApplyDetails inputApplyDetails);

    int updateInputNum(InputApplyDetails inputApplyDetails);

    InputApplyDetails selectInputInfoByMaId(InputApplyDetails inputApplyDetails);

    List<InputApplyDetails> selectInputTaskStatus(InputApplyDetails inputApplyDetails);
}
