package com.bonus.material.input.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.input.domain.InputApplyDetails;
import com.bonus.material.input.service.IInputApplyDetailsService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 入库任务详细Controller
 *
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "入库任务详细接口")
@RestController
@RequestMapping("/input_apply_details")
public class InputApplyDetailsController extends BaseController {
    @Autowired
    private IInputApplyDetailsService inputApplyDetailsService;

    /**
     * 查询入库任务详细列表
     */
    @ApiOperation(value = "查询入库任务详细列表")
    @RequiresPermissions("input:details:list")
    @GetMapping("/list")
    public TableDataInfo list(InputApplyDetails inputApplyDetails) {
        startPage();
        List<InputApplyDetails> list = inputApplyDetailsService.selectInputApplyDetailsList(inputApplyDetails);
        return getDataTable(list);
    }

    /**
     * 导出入库任务详细列表
     */
    @ApiOperation(value = "导出入库任务详细列表")
    @PreventRepeatSubmit
    @RequiresPermissions("input:details:export")
    @SysLog(title = "入库任务详细", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出入库任务详细")
    @PostMapping("/export")
    public void export(HttpServletResponse response, InputApplyDetails inputApplyDetails) {
        List<InputApplyDetails> list = inputApplyDetailsService.selectInputApplyDetailsList(inputApplyDetails);
        ExcelUtil<InputApplyDetails> util = new ExcelUtil<InputApplyDetails>(InputApplyDetails.class);
        util.exportExcel(response, list, "入库任务详细数据");
    }

    /**
     * 获取入库任务详细详细信息
     */
    @ApiOperation(value = "获取入库任务详细详细信息")
    @RequiresPermissions("input:details:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(inputApplyDetailsService.selectInputApplyDetailsById(id));
    }

    /**
     * 新增入库任务详细
     */
    @ApiOperation(value = "新增入库任务详细")
    @PreventRepeatSubmit
    @RequiresPermissions("input:details:add")
    @SysLog(title = "入库任务详细", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增入库任务详细")
    @PostMapping
    public AjaxResult add(@RequestBody InputApplyDetails inputApplyDetails) {
        try {
            return toAjax(inputApplyDetailsService.insertInputApplyDetails(inputApplyDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改入库任务详细
     */
    @ApiOperation(value = "修改入库任务详细")
    @PreventRepeatSubmit
    @RequiresPermissions("input:details:edit")
    @SysLog(title = "入库任务详细", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改入库任务详细")
    @PutMapping
    public AjaxResult edit(@RequestBody InputApplyDetails inputApplyDetails) {
        try {
            return toAjax(inputApplyDetailsService.updateInputApplyDetails(inputApplyDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除入库任务详细
     */
    @ApiOperation(value = "删除入库任务详细")
    @PreventRepeatSubmit
    @RequiresPermissions("input:details:remove")
    @SysLog(title = "入库任务详细", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除入库任务详细")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(inputApplyDetailsService.deleteInputApplyDetailsByIds(ids));
    }





}
